==> hms_room_kit-1.0.0.tar.gz: lib/src/preview_for_role/preview_for_role_header.dart <==
///Package imports
import 'package:flutter/cupertino.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:hms_room_kit/hms_room_kit.dart';
import 'package:provider/provider.dart';
import 'package:tuple/tuple.dart';

///Project imports
import 'package:hms_room_kit/src/layout_api/hms_room_layout.dart';
import 'package:hms_room_kit/src/meeting/meeting_store.dart';

///[PreviewForRoleHeader] is the header of the PreviewForRole screen
///It shows the logo, the LIVE icon and the number of participants
class PreviewForRoleHeader extends StatefulWidget {
  const PreviewForRoleHeader({super.key});

  @override
  State<PreviewForRoleHeader> createState() => _PreviewForRoleHeaderState();
}

class _PreviewForRoleHeaderState extends State<PreviewForRoleHeader> {
  @override
  Widget build(BuildContext context) {
    return Positioned(
      top: 16,
      left: 24,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Row(
            children: [
              ///We render the logo as set in the dashboard
              HMSRoomLayout.roleLayoutData?.logo?.url == null
                  ? Container()
                  : HMSRoomLayout.roleLayoutData!.logo!.url!.contains("svg")
                      ? SvgPicture.network(
                          HMSRoomLayout.roleLayoutData!.logo!.url!)
                      : Image.network(
                          HMSRoomLayout.roleLayoutData!.logo!.url!,
                          height: 30,
                          width: 30,
                        ),
              const SizedBox(
                width: 12,
              ),

              ///We render the LIVE icon based on the HLS streaming status
              ///If the HLS streaming is started we show the LIVE icon
              ///If the HLS streaming is not started we show nothing
              Selector<MeetingStore, bool>(
                  selector: (_, meetingStore) =>
                      meetingStore.streamingType['hls'] ?? false,
                  builder: (_, isHLSStrted, __) {
                    return isHLSStrted
                        ? Container(
                            height: 24,
                            width: 43,
                            decoration: BoxDecoration(
                                color: HMSThemeColors.alertErrorDefault,
                                borderRadius: BorderRadius.circular(4)),
                            child: Center(
                              child: HMSTitleText(
                                  text: "LIVE",
                                  fontSize: 10,
                                  lineHeight: 16,
                                  letterSpacing: 1.5,
                                  textColor: HMSThemeColors.alertErrorBrighter),
                            ),
                          )
                        : Container();
                  }),
              const SizedBox(
                width: 8,
              ),

              ///We render the recording icon based on the recording status
              ///If the recording is started we show the recording icon
              ///If the recording is not started we show nothing
              Selector<MeetingStore, Tuple3<bool, bool, bool>>(
                  selector: (_, meetingStore) => Tuple3(
                        meetingStore.recordingType["browser"] ?? false,
                        meetingStore.recordingType["server"] ?? false,
                        meetingStore.recordingType["hls"] ?? false,
                      ),
                  builder: (_, data, __) {
                    return (data.item1 || data.item2 || data.item3)
                        ? SvgPicture.asset(
                            "packages/hms_room_kit/lib/src/assets/icons/record.svg",
                            height: 24,
                            width: 24,
                            colorFilter: ColorFilter.mode(
                                HMSThemeColors.alertErrorDefault,
                                BlendMode.srcIn),
                          )
                        : Container();
                  }),
              const SizedBox(
                width: 8,
              ),

              ///This renders the number of peers
              ///If the HLS streaming is started, we render the number of peers
              ///else we render an empty Container
              Selector<MeetingStore, Tuple2<bool, int>>(
                  selector: (_, meetingStore) => Tuple2(
                      meetingStore.streamingType['hls'] ?? false,
                      meetingStore.peers.length),
                  builder: (_, data, __) {
                    return data.item1
                        ? Container(
                            width: 59,
                            height: 24,
                            decoration: BoxDecoration(
                                border: Border.all(
                                    color: HMSThemeColors.borderBright,
                                    width: 1),
                                borderRadius:
                                    const BorderRadius.all(Radius.circular(4)),
                                color: HMSThemeColors.backgroundDim
                                    .withOpacity(0.64)),
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.center,
                              children: [
                                SvgPicture.asset(
                                  "packages/hms_room_kit/lib/src/assets/icons/watching.svg",
                                  width: 16,
                                  height: 16,
                                  colorFilter: ColorFilter.mode(
                                      HMSThemeColors.onSurfaceHighEmphasis,
                                      BlendMode.srcIn),
                                  semanticsLabel: "fl_watching",
                                ),
                                const SizedBox(
                                  width: 4,
                                ),
                                HMSTitleText(
                                    text: Utilities.formatNumber(data.item2),
                                    fontSize: 10,
                                    lineHeight: 10,
                                    letterSpacing: 1.5,
                                    textColor:
                                        HMSThemeColors.onSurfaceHighEmphasis)
                              ],
                            ))
                        : Container();
                  })
            ],
          ),
        ],
      ),
    );
  }
}

==> hms_room_kit-1.0.3.tar.gz: lib/src/preview_for_role/preview_for_role_header.dart <==
///Package imports
import 'package:flutter/cupertino.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:hms_room_kit/hms_room_kit.dart';
import 'package:provider/provider.dart';
import 'package:tuple/tuple.dart';

///Project imports
import 'package:hms_room_kit/src/layout_api/hms_room_layout.dart';
import 'package:hms_room_kit/src/meeting/meeting_store.dart';

///[PreviewForRoleHeader] is the header of the PreviewForRole screen
///It shows the logo, the LIVE icon and the number of participants
class PreviewForRoleHeader extends StatefulWidget {
  const PreviewForRoleHeader({super.key});

  @override
  State<PreviewForRoleHeader> createState() => _PreviewForRoleHeaderState();
}

class _PreviewForRoleHeaderState extends State<PreviewForRoleHeader> {
  @override
  Widget build(BuildContext context) {
    return Positioned(
      top: 16,
      left: 24,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Row(
            children: [
              ///We render the logo as set in the dashboard
              HMSRoomLayout.roleLayoutData?.logo?.url == null
                  ? Container()
                  : HMSRoomLayout.roleLayoutData!.logo!.url!.contains("svg")
                      ? SvgPicture.network(
                          HMSRoomLayout.roleLayoutData!.logo!.url!)
                      : Image.network(
                          HMSRoomLayout.roleLayoutData!.logo!.url!,
                          height: 30,
                          width: 30,
                        ),
              const SizedBox(
                width: 12,
              ),

              ///We render the LIVE icon based on the HLS streaming status
              ///If the HLS streaming is started we show the LIVE icon
              ///If the HLS streaming is not started we show nothing
              Selector<MeetingStore, bool>(
                  selector: (_, meetingStore) =>
                      meetingStore.streamingType['hls'] ?? false,
                  builder: (_, isHLSStrted, __) {
                    return isHLSStrted
                        ? Container(
                            height: 24,
                            width: 43,
                            decoration: BoxDecoration(
                                color: HMSThemeColors.alertErrorDefault,
                                borderRadius: BorderRadius.circular(4)),
                            child: Center(
                              child: HMSTitleText(
                                  text: "LIVE",
                                  fontSize: 10,
                                  lineHeight: 16,
                                  letterSpacing: 1.5,
                                  textColor: HMSThemeColors.alertErrorBrighter),
                            ),
                          )
                        : Container();
                  }),
              const SizedBox(
                width: 8,
              ),

              ///We render the recording icon based on the recording status
              ///If the recording is started we show the recording icon
              ///If the recording is not started we show nothing
              Selector<MeetingStore, Tuple3<bool, bool, bool>>(
                  selector: (_, meetingStore) => Tuple3(
                        meetingStore.recordingType["browser"] ?? false,
                        meetingStore.recordingType["server"] ?? false,
                        meetingStore.recordingType["hls"] ?? false,
                      ),
                  builder: (_, data, __) {
                    return (data.item1 || data.item2 || data.item3)
                        ? SvgPicture.asset(
                            "packages/hms_room_kit/lib/src/assets/icons/record.svg",
                            height: 24,
                            width: 24,
                            colorFilter: ColorFilter.mode(
                                HMSThemeColors.alertErrorDefault,
                                BlendMode.srcIn),
                          )
                        : Container();
                  }),
              const SizedBox(
                width: 8,
              ),

              ///This renders the number of peers
              ///If the HLS streaming is started, we render the number of peers
              ///else we render an empty Container
              Selector<MeetingStore, Tuple2<bool, int>>(
                  selector: (_, meetingStore) => Tuple2(
                      meetingStore.streamingType['hls'] ?? false,
                      meetingStore.peersInRoom),
                  builder: (_, data, __) {
                    return data.item1
                        ? Container(
                            width: 59,
                            height: 24,
                            decoration: BoxDecoration(
                                border: Border.all(
                                    color: HMSThemeColors.borderBright,
                                    width: 1),
                                borderRadius:
                                    const BorderRadius.all(Radius.circular(4)),
                                color: HMSThemeColors.backgroundDim
                                    .withOpacity(0.64)),
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.center,
                              children: [
                                SvgPicture.asset(
                                  "packages/hms_room_kit/lib/src/assets/icons/watching.svg",
                                  width: 16,
                                  height: 16,
                                  colorFilter: ColorFilter.mode(
                                      HMSThemeColors.onSurfaceHighEmphasis,
                                      BlendMode.srcIn),
                                  semanticsLabel: "fl_watching",
                                ),
                                const SizedBox(
                                  width: 4,
                                ),
                                HMSTitleText(
                                    text: Utilities.formatNumber(data.item2),
                                    fontSize: 10,
                                    lineHeight: 10,
                                    letterSpacing: 1.5,
                                    textColor:
                                        HMSThemeColors.onSurfaceHighEmphasis)
                              ],
                            ))
                        : Container();
                  })
            ],
          ),
        ],
      ),
    );
  }
}
